%% load_constants.m
%% 
%% This script defines all the system parameters used by the
%% 	hopper simulation.
%%   _
%%  | |
%%  | |  m1   ^
%%  | |       |
%%   -        |
%%   |   k,b  |y1
%%   |        |
%% ----- m2   |  
%%  ---       |   ^
%% 			  |   |y2
%%________    |   |
%% 
%% Change the values of:
%% 
%%   m1 		: the mass of the body
%%   m2         : the mass of the foot
%%   k  		: the stiffness of the spring
%%	 period     : the period of the activation
%% 
%% INCLUDES MAX EXTENSION OF SPRING


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% SIMULATION PARAMETERS

t_start = 0;						% Simulation start time
t_final = 10;						% Simulation end time

y0 = [-0.01 0 0 0]';		% initial conditions

                                        % 		| y1		|
										% 		| y1_dot	|
										% Y =   | y2		|
										% 		| y2_dot	|

                              
hopper.m1 = 0.300;         % (Kg) mass of body
hopper.m2 = 0.001;         % (Kg) mass of the foot
								
hopper.k = 300;            % (N/m) Spring Stiffness (approx 1 cm compression at rest)
hopper.b = 3;              % (Ns/m) damping constant

hopper.max_ext = 0.04;      % (m) Maximum spring extension
                            % WATCH OUT FOR k*max_ex = F

hopper.frequency = 0.5;      % (Hz) actuator frequency
hopper.duty = .35;         %  actuator duty cycle
hopper.F = 10;             % Actuator force (N)

hopper.g = 9.8;            % (m/s^2) gravity

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% DERIVED VALUES
hopper.period = 1/hopper.frequency;			% compute the period

hopper.fn = sqrt(hopper.k/hopper.m1)/(2*pi);        % natural frequency of sprung mass
hopper.z = hopper.b*0.5/sqrt(hopper.m1*hopper.k);	% damping ration of sprung mass

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% MORE OBSCURE SIMULATION PARAMETERS
hopper.ss_tolerance = 0.05;    %resolution required to declare steady state
                               % in percent of hopping height

% FORCE STATES
hopper.ON = 1;
hopper.OFF = 0;

% EVENTS
hopper.TAKEOFF = 1;
hopper.TOUCHDOWN = 1;
hopper.BEGIN_FORCE = 2;
hopper.END_FORCE = 3;
hopper.HIT_LIMIT = 4;
hopper.OFF_LIMIT = 4;

% FOOT STATES
hopper.AIR = 0;
hopper.GROUND = 1;

% EXTENSION STATES
hopper.LIMIT = 0;
hopper.FREE = 1;





